@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2015-01-15'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-02-27'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -96,8 +96,18 @@ sub gen_help {
     {
         my $subcommands = $args{subcommands} or last;
         push @help, "Subcommands:\n";
-        for (sort keys %$subcommands) {
-            push @help, "  $_\n";
+        if (keys(%$subcommands) >= 12) {
+            # comma-separated list
+            require Text::Wrap;
+            local $Text::Wrap::columns = $ENV{COLUMNS} // 80;
+            push @help, Text::Wrap::wrap(
+                "  ", "  ", join(", ", sort keys %$subcommands)), "\n";
+        } else {
+            for my $sc_name (sort keys %$subcommands) {
+                my $sc_spec = $subcommands->{$sc_name};
+                next unless $sc_spec->{show_in_help} //1;
+                push @help, "  $sc_name\n";
+            }
         }
     }
 
@@ -218,7 +228,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-01-15.
+This document describes version 0.03 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-02-27.
 
 =head1 DESCRIPTION
 
@@ -231,7 +241,7 @@ formatting options first though).
 
 =head2 gen_help(%args) -> [status, msg, result, meta]
 
-{en_US Generate help message for Perinci::CmdLine-based app}.
+Generate help message for Perinci::CmdLine-based app.
 
 Arguments ('*' denotes required arguments):
 
@@ -241,7 +251,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<meta>* => I<hash>
 
-{en_US Function metadata, must be normalized}.
+Function metadata, must be normalized.
 
 =item * B<per_arg_json> => I<bool>
 
